@@ -47,17 +47,3 @@ class Delete(Command):
         args.update(vars(parsed_args))
         host = host_factory(**args)
         host.delete()
-
-
-class Inventory(Command):
-    "Write an ansible compatible inventory of all hosts"
-
-    def get_parser(self, prog_name):
-        parser = super().get_parser(prog_name)
-        return set_common_options(parser)
-
-    def take_action(self, parsed_args):
-        args = vars(self.app.options)
-        args.update(vars(parsed_args))
-        host = host_factory(**args)
-        host.write_inventory()
